@@ -3,7 +3,7 @@ use warnings;
 
 use Moops;
 
-our $VERSION = '0.1000'; # VERSION
+our $VERSION = '0.1001'; # VERSION
 # PODNAME: Stenciller.pm
 library Types::Stenciller
 
@@ -13,7 +13,7 @@ declares Stencil, Renderer, Stenciller
 
 {
 
-    class_type Stenciller => { class => 'Stenciller' };
+    class_type Stenciller => { class => 'Stenciller::Wrap' };
     class_type Stencil    => { class => 'Stenciller::Stencil' };
 
 }
@@ -32,7 +32,7 @@ Stenciller.pm
 
 =head1 VERSION
 
-Version 0.1000, released 2015-01-15.
+Version 0.1001, released 2015-01-15.
 
 =head1 SYNOPSIS
 
@@ -42,7 +42,7 @@ Version 0.1000, released 2015-01-15.
 
 Defines a few types used in the C<Stenciller> namespace.
 
-
+:splint classname Types::Stenciller
 
 =head1 TYPES
 
